% Figures 1 to 2 in "The Limited Power of Monetary Policy in a Pandemic",
% Antoine Lepetit and Cristina Fuentes-Albero, May 2022.
% This program reads the matrices mp_pandemic_zlb_results.mat and mp_pandemic_zlb_cont_results.mat 

baseline     		= load('mp_pandemic_zlb_results.mat');
containment		= load('mp_pandemic_zlb_cont_results.mat');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMPARISON 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% % Output
figure(111);
plot(100*(baseline.oo_.endo_simul(12,2:100)-1), 'r--','LineWidth',2.5);
hold on
plot(100*(containment.oo_.endo_simul(12,2:100)-1), 'b','LineWidth',2.5);
hold on
xlabel('Weeks','FontSize',18);
ylabel('Percentage deviation','FontSize',18);
saveas(gcf,'figures/fig2_output.eps','epsc')

% % Consumption
figure(222);
plot(100*(baseline.oo_.endo_simul(14,2:100)-1), 'r--','LineWidth',2.5);
hold on
plot(100*(containment.oo_.endo_simul(14,2:100)-1), 'b','LineWidth',2.5);
hold on
xlabel('Weeks','FontSize',18);
ylabel('Percentage deviation','FontSize',18);
saveas(gcf,'figures/fig2_consumption.eps','epsc')

% % Inflation
figure(333);
plot(100*(baseline.oo_.endo_simul(9,2:100)-1), 'r--','LineWidth',2.5);
hold on
plot(100*(containment.oo_.endo_simul(9,2:100)-1), 'b','LineWidth',2.5);
hold on
xlabel('Weeks','FontSize',18);
ylabel('Percentage points (weekly)','FontSize',18);
saveas(gcf,'figures/fig2_inflation.eps','epsc')

% % Policy rate
figure(444);
plot(100*baseline.oo_.endo_simul(10,2:100),  'r--','LineWidth',2.5);
hold on;
plot(100*containment.oo_.endo_simul(10,2:100), 'b','LineWidth',2.5);
hold on;
xlabel('Weeks','FontSize',18);
ylabel('Percentage points (weekly)','FontSize',18);
saveas(gcf,'figures/fig2_ffr.eps','epsc')

% Weekly deaths
figure(555);
%plot(338752267.*diff(baseline.oo_.endo_simul(5,2:100)),'b','LineWidth',2.5);
%hold on;
%plot(338752267.*diff(containment.oo_.endo_simul(5,2:100)),'--','LineWidth',2.5);
%hold on;
plot((baseline.oo_.endo_simul(5,2:100)), 'r--','LineWidth',2.5);
hold on;
plot((containment.oo_.endo_simul(5,2:100)),'b','LineWidth',2.5);
hold on;
xlabel('Weeks','FontSize',18);
ylabel('Fraction of population','FontSize',18);
saveas(gcf,'figures/fig1_death.eps','epsc')

% Infected
figure(777);
plot(baseline.oo_.endo_simul(3,2:100),  'r--', 'Linewidth',2.5);
hold on;
plot(containment.oo_.endo_simul(3,2:100), 'b', 'Linewidth',2.5);
hold on;
xlabel('Weeks','FontSize',18);
ylabel('Fraction of population','FontSize',18);
saveas(gcf,'figures/fig1_infected.eps','epsc')

% Susceptible
figure(888);
plot(baseline.oo_.endo_simul(2,2:100),  'r--', 'Linewidth',2.5);
hold on;
plot(containment.oo_.endo_simul(2,2:100), 'b', 'Linewidth',2.5);
hold on;
xlabel('Weeks','FontSize',18);
ylabel('Fraction of population','FontSize',18);
saveas(gcf,'figures/fig1_susceptible.eps','epsc')

% Newly Infected
figure(1111);
plot(baseline.oo_.endo_simul(1,2:100),  'r--', 'Linewidth',2.5);
hold on;
plot(containment.oo_.endo_simul(1,2:100), 'b', 'Linewidth',2.5);
hold on;
xlabel('Weeks','FontSize',18);
ylabel('Fraction of population','FontSize',18);
saveas(gcf,'figures/fig1_newinfected.eps','epsc')
