% Figures 6 and 7 in "The Limited Power of Monetary Policy in a Pandemic",
% Antoine Lepetit and Cristina Fuentes-Albero, May 2022.

%% Preparation

clear all
clc

mp_pandemic_zlb_cont;

global M_ options_ oo_;
Tsim = 150;
options_.periods = Tsim;
options_.simul.maxit = 200; 
options_.dynatol.f = 1e-10;
options_.dynatol.x = 1e-10;

maxlag=1;
maxlead=1;
endo_simul = repmat(oo_.endo_simul(:,1),[1,Tsim+maxlag+maxlead]);
endo_simul(:,end) = oo_.endo_simul(:,end);
oo_.endo_simul = endo_simul;

% Calibrate shocks

covid_19 =[0.005;zeros(Tsim,1)];
mp_shock = [zeros(Tsim+1,1)];

shocks = [mp_shock,covid_19];

eps_t = shocks(1:2,:);
Tshock = size(eps_t,1);
nshock = size(eps_t,2);

%% Simulate baseline

Xn_baseline = endo_simul;

for h=1:Tshock
    
    display(sprintf('Now on time %d', h));
    
    options_.periods = Tsim-h+1;
    
    oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[zeros(Tsim-h+1,1),zeros(Tsim-h+1,1)]];
    perfect_foresight_solver;
    
    Xn_baseline(:,h+1:end) = real(oo_.endo_simul(:,2:end));
    oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
end

clear oo_.endo_simul oo_.exo_simul shocks eps_t Tshock nshock;

% Pick up path for FFR

rff_treshold =  Xn_baseline(10,2:end)';
ffr_trigger = rff_treshold;


%% Simulate sim with extended path - 2 quarters

counter_shock = ones(Tsim+1,1);

shocks = [mp_shock,covid_19,ffr_trigger,counter_shock];
eps_t = shocks(1:2,:);
Tshock = size(eps_t,1);
nshock = size(eps_t,2);

mp_pandemic_extended2Q_cont

endo_simul = repmat(oo_.endo_simul(:,1),[1,Tsim+maxlag+maxlead]);
endo_simul(:,end) = oo_.endo_simul(:,end);
oo_.endo_simul = endo_simul;

Xn_extended2Q = endo_simul;

for h=1:Tshock
    
    display(sprintf('Now on time %d', h));
    
    options_.periods = Tsim-h+1;
    
    oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[zeros(Tsim-h+1,1),zeros(Tsim-h+1,1),ffr_trigger(h+1:end),counter_shock(h+1:end)]];
    perfect_foresight_solver;
    
    Xn_extended2Q(:,h+1:end) = real(oo_.endo_simul(:,2:end));
    oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
end

clear oo_.endo_simul oo_.exo_simul shocks eps_t Tshock nshock;


%% Simulate sim with extended path - 4 quarters

counter_shock = ones(Tsim+1,1);

shocks = [mp_shock,covid_19,ffr_trigger,counter_shock];
eps_t = shocks(1:2,:);
Tshock = size(eps_t,1);
nshock = size(eps_t,2);

mp_pandemic_extended4Q_cont

endo_simul = repmat(oo_.endo_simul(:,1),[1,Tsim+maxlag+maxlead]);
endo_simul(:,end) = oo_.endo_simul(:,end);
oo_.endo_simul = endo_simul;

Xn_extended4Q = endo_simul;

for h=1:Tshock
    
    display(sprintf('Now on time %d', h));
    
    options_.periods = Tsim-h+1;
    
    oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[zeros(Tsim-h+1,1),zeros(Tsim-h+1,1),ffr_trigger(h+1:end),counter_shock(h+1:end)]];
    perfect_foresight_solver;
    
    Xn_extended4Q(:,h+1:end) = real(oo_.endo_simul(:,2:end));
    oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
end

clear oo_.endo_simul oo_.exo_simul mp_shock shocks eps_t Tshock nshock;

%% Figures

figure(1);
plot(Xn_baseline(3,2:100),'LineWidth',3);
hold on
plot(Xn_extended2Q(3,2:100),'--','LineWidth',3);
hold on
plot(Xn_extended4Q(3,2:100),':','LineWidth',3);
%title('Infected','Fontsize',20)
xlabel('Weeks','Fontsize',18)
ylabel('Fraction of the population','Fontsize',18)
saveas(gcf,'figures/fig6_infected.eps','epsc')

figure(2);
plot(Xn_baseline(2,2:100),'LineWidth',3);
hold on
plot(Xn_extended2Q(2,2:100),'--','LineWidth',3);
hold on
plot(Xn_extended4Q(2,2:100),':','LineWidth',3);
%title('Susceptible','Fontsize',20)
xlabel('Weeks','Fontsize',18)
ylabel('Fraction of the population','Fontsize',18)
saveas(gcf,'figures/fig6_susceptible.eps','epsc')

figure(3);
plot((Xn_baseline(12,2:100)-1)*100,'LineWidth',3);
hold on
plot((Xn_extended2Q(12,2:100)-1)*100,'--','LineWidth',3);
hold on
plot((Xn_extended4Q(12,2:100)-1)*100,':','LineWidth',3);
%title('Output','Fontsize',20)
xlabel('Weeks','Fontsize',18)
ylabel('Percentage deviation','Fontsize',18)
saveas(gcf,'figures/fig6_output.eps','epsc')

figure(4);
plot((Xn_baseline(14,2:100)-1)*100,'LineWidth',3);
hold on
plot((Xn_extended2Q(14,2:100)-1)*100,'--','LineWidth',3);
hold on
plot((Xn_extended4Q(14,2:100)-1)*100,':','LineWidth',3);
%title('Consumption','Fontsize',20)
xlabel('Weeks','Fontsize',18)
ylabel('Percentage deviation','Fontsize',18)
saveas(gcf,'figures/fig6_consumption.eps','epsc')

figure(5);
plot((Xn_baseline(9,2:100)-1)*100,'LineWidth',3);
hold on
plot((Xn_extended2Q(9,2:100)-1)*100,'--','LineWidth',3);
hold on
plot((Xn_extended4Q(9,2:100)-1)*100,':','LineWidth',3);
%title('Inflation','Fontsize',20)
xlabel('Weeks','Fontsize',18)
ylabel('Percentage points (weekly)','Fontsize',18)
saveas(gcf,'figures/fig6_inflation.eps','epsc')

figure(6);
plot(Xn_baseline(10,2:100)*100,'LineWidth',3);
hold on
plot(Xn_extended2Q(10,2:100)*100,'--','LineWidth',3);
hold on
plot(Xn_extended4Q(10,2:100)*100,':','LineWidth',3);
%title('Policy rate','Fontsize',20)
xlabel('Weeks','Fontsize',18)
ylabel('Percentage points (weekly)','Fontsize',18)
saveas(gcf,'figures/fig6_ffr.eps','epsc')

figure(7);
plot(Xn_baseline(5,2:100),'LineWidth',3);
hold on
plot(Xn_extended2Q(5,2:100),'--','LineWidth',3);
hold on
plot(Xn_extended4Q(5,2:100),':','LineWidth',3);
%title('Death rate','Fontsize',20)
xlabel('Weeks','FontSize',18);
ylabel('Fraction of population','FontSize',18);
saveas(gcf,'figures/fig6_death.eps','epsc')

figure(8);
plot(Xn_baseline(24,2:100),'LineWidth',3);
hold on
plot(Xn_extended2Q(24,2:100),'--','LineWidth',3);
hold on
plot(Xn_extended4Q(24,2:100),':','LineWidth',3);
%title('Contaiment rate','Fontsize',20)
xlabel('Weeks','Fontsize',18)
saveas(gcf,'figures/fig6_mu.eps','epsc')
