% Figure 9 in "The Limited Power of Monetary Policy in a Pandemic", 
% Antoine Lepetit and Cristina Fuentes-Albero, May 2022.

%% Preparation

clear all
clc

mp_pandemic_nozlb_cont;

global M_ options_ oo_;
Tsim = 200;
options_.periods = Tsim;
options_.simul.maxit = 200; 
options_.dynatol.f = 1e-10;
options_.dynatol.x = 1e-10;

maxlag=1;
maxlead=1;
endo_simul = repmat(oo_.endo_simul(:,1),[1,Tsim+maxlag+maxlead]);
endo_simul(:,end) = oo_.endo_simul(:,end);
oo_.endo_simul = endo_simul;

% Calibrate shocks
covid_19 =[0.005;zeros(Tsim,1)];
mp_shock = [zeros(Tsim+1,1)];

shocks = [mp_shock,covid_19];

eps_t = shocks(1:2,:);
Tshock = size(eps_t,1);
nshock = size(eps_t,2);

%% Simulate baseline

Xn_baseline = endo_simul;

for h=1:Tshock
    
    display(sprintf('Now on time %d', h));
    
    options_.periods = Tsim-h+1;
    
    oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[zeros(Tsim-h+1,1),zeros(Tsim-h+1,1)]];
    perfect_foresight_solver;
    
    Xn_baseline(:,h+1:end) = real(oo_.endo_simul(:,2:end));
    oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
end

clear oo_.endo_simul oo_.exo_simul shocks eps_t Tshock nshock;

%% Simulate alt-sims with unanticipated monetary policy shocks happening in different periods

Xn = zeros(25,202,100);

  % Time 10

  j=10;
    
  mp_shock = [zeros(j,1);-0.0001;zeros(Tsim+1-(j+1),1)];

  shocks = [mp_shock,covid_19]; 

  eps_t = shocks(1:j+1,:);
  Tshock = size(eps_t,1);
  nshock = size(eps_t,2);

  oo_.endo_simul = endo_simul;
  Xn(:,:,j) = endo_simul;

  for h=1:Tshock
    
      display(sprintf('Now on time %d', h));
    
      options_.periods = Tsim-h+1;
    
      oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[zeros(Tsim-h+1,1),zeros(Tsim-h+1,1)]];
      perfect_foresight_solver;
    
      Xn(:,h+1:end,j) = real(oo_.endo_simul(:,2:end));
      oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
  end
  
  clear oo_.endo_simul oo_.exo_simul mp_shock shocks eps_t Tshock nshock;
  
  % Time 30

  j=30;
    
  mp_shock = [zeros(j,1);-0.0001;zeros(Tsim+1-(j+1),1)];

  shocks = [mp_shock,covid_19]; 

  eps_t = shocks(1:j+1,:);
  Tshock = size(eps_t,1);
  nshock = size(eps_t,2);

  oo_.endo_simul = endo_simul;
  Xn(:,:,j) = endo_simul;

  for h=1:Tshock
    
      display(sprintf('Now on time %d', h));
    
      options_.periods = Tsim-h+1;
    
      oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[zeros(Tsim-h+1,1),zeros(Tsim-h+1,1)]];
      perfect_foresight_solver;
    
      Xn(:,h+1:end,j) = real(oo_.endo_simul(:,2:end));
      oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
  end
  
  clear oo_.endo_simul oo_.exo_simul mp_shock shocks eps_t Tshock nshock;
  
  % Time 50

  j=50;
    
  mp_shock = [zeros(j,1);-0.0001;zeros(Tsim+1-(j+1),1)];

  shocks = [mp_shock,covid_19]; 

  eps_t = shocks(1:j+1,:);
  Tshock = size(eps_t,1);
  nshock = size(eps_t,2);

  oo_.endo_simul = endo_simul;
  Xn(:,:,j) = endo_simul;

  for h=1:Tshock
    
      display(sprintf('Now on time %d', h));
    
      options_.periods = Tsim-h+1;
    
      oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[zeros(Tsim-h+1,1),zeros(Tsim-h+1,1)]];
      perfect_foresight_solver;
    
      Xn(:,h+1:end,j) = real(oo_.endo_simul(:,2:end));
      oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
  end
  
  clear oo_.endo_simul oo_.exo_simul mp_shock shocks eps_t Tshock nshock;
  
  % Time 100

  j=100;
    
  mp_shock = [zeros(j,1);-0.0001;zeros(Tsim+1-(j+1),1)];

  shocks = [mp_shock,covid_19]; 

  eps_t = shocks(1:j+1,:);
  Tshock = size(eps_t,1);
  nshock = size(eps_t,2);

  oo_.endo_simul = endo_simul;
  Xn(:,:,j) = endo_simul;

  for h=1:Tshock
    
      display(sprintf('Now on time %d', h));
    
      options_.periods = Tsim-h+1;
    
      oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[zeros(Tsim-h+1,1),zeros(Tsim-h+1,1)]];
      perfect_foresight_solver;
    
      Xn(:,h+1:end,j) = real(oo_.endo_simul(:,2:end));
      oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
  end
  
  clear oo_.endo_simul oo_.exo_simul mp_shock shocks eps_t Tshock nshock;
  
  %% Figures
   
  figure(1);
  plot(100.*(Xn(12,12:112,10)-Xn_baseline(12,12:112))./Xn_baseline(12,12:112),'Linewidth',3)
  hold on
  plot(100.*(Xn(12,32:132,30)-Xn_baseline(12,32:132))./Xn_baseline(12,32:132),'--','Linewidth',3)
  hold on
  plot(100.*(Xn(12,52:152,50)-Xn_baseline(12,52:152))./Xn_baseline(12,52:152),'-.','Linewidth',3)
  hold on
  plot(100.*(Xn(12,102:202,100)-Xn_baseline(12,102:202))./Xn_baseline(12,102:202),':','Linewidth',3)
  xlabel('Weeks after the shock','Fontsize',16)
  ylabel('Percentage deviation','Fontsize',16)
  xlim([0 100])
 % legend('Shock at time 10','Shock at time 30','Shock at time 50','Shock at time 100 - "normal times"','Fontsize',12)
  saveas(gcf,'figures/fig9_output.eps','epsc')

  
  figure(2);
  plot(100.*(Xn(14,12:112,10)-Xn_baseline(14,12:112))./Xn_baseline(14,12:112),'Linewidth',3)
  hold on
  plot(100.*(Xn(14,32:132,30)-Xn_baseline(14,32:132))./Xn_baseline(14,32:132),'--','Linewidth',3)
  hold on
  plot(100.*(Xn(14,52:152,50)-Xn_baseline(14,52:152))./Xn_baseline(14,52:152),'-.','Linewidth',3)
  hold on
  plot(100.*(Xn(14,102:202,100)-Xn_baseline(14,102:202))./Xn_baseline(14,102:202),':','Linewidth',3)
  xlabel('Weeks after the shock','Fontsize',16)
  ylabel('Percentage deviation','Fontsize',16)
  xlim([0 100])
%  legend('Shock at time 10','Shock at time 30','Shock at time 50','Shock at time 100 - "normal times"','Fontsize',12)
 saveas(gcf,'figures/fig9_consumption.eps','epsc')


  figure(3);
  plot(Xn(3,12:112,10)-Xn_baseline(3,12:112),'Linewidth',3)
  hold on
  plot(Xn(3,32:132,30)-Xn_baseline(3,32:132),'--','Linewidth',3)
  hold on
  plot(Xn(3,52:152,50)-Xn_baseline(3,52:152),'-.','Linewidth',3)
  hold on
  plot(Xn(3,102:202,100)-Xn_baseline(3,102:202),':','Linewidth',3)
  xlabel('Weeks after the shock','Fontsize',16)
  ylabel('Level deviation','Fontsize',16)
  xlim([0 100])
 % legend('Shock at time 10','Shock at time 30','Shock at time 50','Shock at time 100 - "normal times"','Fontsize',12)
 saveas(gcf,'figures/fig9_infected.eps','epsc')

  figure(4);
  plot(Xn(2,12:112,10)-Xn_baseline(2,12:112),'Linewidth',3)
  hold on
  plot(Xn(2,32:132,30)-Xn_baseline(2,32:132),'--','Linewidth',3)
  hold on
  plot(Xn(2,52:152,50)-Xn_baseline(2,52:152),'-.','Linewidth',3)
  hold on
  plot(Xn(2,102:202,100)-Xn_baseline(2,102:202),':','Linewidth',3)
  xlabel('Weeks after the shock','Fontsize',16)
  ylabel('Level deviation','Fontsize',16)
  xlim([0 100])
  %legend('Shock at time 10','Shock at time 30','Shock at time 50','Shock at time 100 - "normal times"','Fontsize',12)
 saveas(gcf,'figures/fig9_susceptible.eps','epsc')

  figure(5);
  plot(Xn(5,12:112,10)-Xn_baseline(5,12:112),'Linewidth',3)
  hold on
  plot(Xn(5,32:132,30)-Xn_baseline(5,32:132),'--','Linewidth',3)
  hold on
  plot(Xn(5,52:152,50)-Xn_baseline(5,52:152),'-.','Linewidth',3)
  hold on
  plot(Xn(5,102:202,100)-Xn_baseline(5,102:202),':','Linewidth',3)
  xlabel('Weeks after the shock','Fontsize',16)
  ylabel('Level deviation','Fontsize',16)
  xlim([0 100])
  %legend('Shock at time 10','Shock at time 30','Shock at time 50','Shock at time 100 - "normal times"','Fontsize',12)
 saveas(gcf,'figures/fig9_death.eps','epsc')

